@@ -292,6 +292,14 @@ class OpenEuler():
                 pkg_name=self.get_rpm_name_from_full_name(full_pkg_name)
                 yield pkg_name,full_pkg_name
 
+    def get_openEuler_core_rpm_list(self,os_version,os_arch):
+        core_src_list=self.get_core_src_list()
+        core_rpm_list=[]
+        for rpm_name,src_name in self.get_openEuler_os_rpm2src(os_version,os_arch):
+            if src_name in core_src_list and rpm_name not in core_rpm_list:
+                core_rpm_list.append(rpm_name)
+        return core_rpm_list
+
     def get_openEuler_everything_rpm_list(self, os_version: str, os_arch: str):
         all_rpm_list = []
         for rpm_name, _ in self.get_openEuler_pkgs(os_version, os_arch, "everything"):
